@@ -17,11 +17,13 @@ def is_successful(xml):
 
 
 def get_data_field(xml, field):
+    """Get the value of a field in the 'Data' part of the LM's XML"""
     value = _get_xml_field(xml, "Data", data_field=field)
     return value or ""
 
 
 def get_data(xml):
+    """Return the 'Data' entry from LM's XML as a dict"""
     success_xml_entry = _get_xml_field(xml, "Success")
     try:
         data = (success_xml_entry['Data']
