@@ -443,6 +443,11 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
             interfaces_data = data.get('Interface', [])
             for iface_data in interfaces_data:
                 iface = build_object(Interface, self.access_info, iface_data)
+                # Check for duplicate IPs as there is a bug in LoadMaster showiface
+                # that makes unset interfaces inherit the previous interfaces IP.
+                for interface in interfaces:
+                    if iface.addr == interface.addr:
+                        iface.addr = None
                 interfaces.append(iface)
             return interfaces
         except KempTechApiException as e:
@@ -454,9 +459,9 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
                 try:
                     response = self._get('/stats')
                     data = get_data(response)
-                    xml_object = data.get('Network', [])
+                    xml_object = data.get('Network', {})
                 except KempTechApiException:
-                    xml_object = []
+                    xml_object = {}
 
                 for k, v in xml_object.items():
                     obj = self.get_interface(v['ifaceID'])
