@@ -1688,8 +1688,16 @@ class Interface(BaseKempObject):
     )
 
     def __init__(self, loadmaster_info, interface):
-        self.interface = interface
+        """ Interface constructor
 
+        :param loadmaster_info: LoadMaster access_info
+        :param interface: LoadMaster interface ID.
+        """
+        self.interface = interface
+        # Set addr and cidr to empty strings to allow the properties
+        # to work correctly when there are no IPs or CIDR set.
+        self.addr = ""
+        self.cidr = ""
         super(Interface, self).__init__(loadmaster_info)
 
     def __str__(self):
@@ -1703,15 +1711,15 @@ class Interface(BaseKempObject):
 
     @address.setter
     def address(self, value):
-        self.addr = value + "/" + self.cidr
+        self.addr = value + "/" + self.cidr if value is not None else None
 
     @property
     def cidr(self):
-        return self.addr.split("/")[1]
+        return self.addr.split("/")[1] if self.addr is not None else None
 
     @cidr.setter
     def cidr(self, value):
-        self.addr = self.address + "/" + value
+        self.addr = self.address + "/" + value if value is not None else None
 
     def save(self, update=True):
         # pylint: disable=duplicate-code
